-  2017

   -  `AMBER developer meeting, Hai
      Nguyen <http://hainm.github.io/talks/amber_meeting_2017/>`__
   -  `PyEMMA 2017, projX: Interative molecular projection
      visualization, Guillermo
      Pérez-Hernández <https://www.youtube.com/watch?v=AT69NfUMV2U>`__

-  2016

   -  `ngl-3dsig, Alexander
      Rose <http://nglviewer.org/talks/ngl-3dsig/>`__
   -  `ngl-web3d, Alexander
      Rose <http://nglviewer.org/talks/ngl-web3d>`__

- Articles/Videos from users
    - `"The universe as balls and springs: molecular dynamics in Python" - Lily Wang (PyCon AU 2019)], <https://youtu.be/X5umNQDqfqQ>`__
    - `Looking at molecules using Python <https://www.youtube.com/watch?v=RWgt1WMwMUs>`__
    - `Visualizing and Analyzing Proteins in Python <https://towardsdatascience.com/visualizing-and-analyzing-proteins-in-python-bd99521ccd>`__
